<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bn">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>অ্যায়েন্ডার মোড সক্রিয়</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>অ্যায়েন্ডার মোড অ্যাক্টিভ</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>দেক্টি করুন</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>বাধ্য করুন</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>অ্যায়েন্ডার মোড</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>অ্যায়েন্ডার মোড সেটিং</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>অ্যায়েন্ডার মোড</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>আমার ডিভাইস</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>ব্লুটুথ সেটিং</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>অ্যাক্টিভ হয়নি</translation>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>অ্যাক্টিভ হয়নি</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>সক্রিয় করুন</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>ব্লুটুথ সেটিং</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 সংযোগ করা হয়েছে</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>সংযোগ করছে...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>ব্লুটুথ</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>অ্যাক্টিভ হয়নি</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>%1 সংযোগ করা হয়েছে</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>সংযোগ করা হয়নি</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>অ্যাক্টিভ হয়নি</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>ব্লুটুথ</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>সাখরণ</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>প্রদর্শন সেটিং</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>প্রদর্শন সেটিং</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>সাখরণ</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>সোনা</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>মঙ্গলবার</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>বুধবার</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>বৃহস্পতিবার</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>শুক্রবার</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>শনিবার</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>শনিবার</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>কীবোর্ড লেআউট যোগ করুন</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>তারিখ ও সময়</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 ঘন্টা সময়</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 ঘন্টা সময়</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>সময় সেটিংস</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>ক্যালেনダー খুলুন</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>মঙ্গলবার</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>বুধবার</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>বৃহস্পতিবার</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>শুক্রবার</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>শনিবার</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>শনিবার</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>রবিবার</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>মঙ্গলবার</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>বুধবার</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>বৃহস্পতিবার</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>শুক্রবার</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>শনিবার</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>শনিবার</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>রবিবার</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>অন্যান্য ডিভাইস</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>DND মোড</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>DND মোডের সেটিংস</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>দিবস্তুনা দিয়ে যাওয়া</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>দিবস্তুনা সক্রিয় করা</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>DND মোড সক্রিয়</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>DND মোড দিবস্তুনা দিয়ে যাওয়া</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>DND মোড</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>বিশ্রাম প্রতিরোধ</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>বিশ্রাম প্রতিরোধ সক্রিয়</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>বিশ্রাম প্রতিরোধ দিবস্তুনা দিয়ে যাওয়া</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>প্রদর্শন সেটিংস</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>বিশ্রাম প্রতিরোধ</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>থিম</translation>
    </message>
    <message>
        <source>On</source>
        <translation>আন</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>অফ</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>সোনালী</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>মোটা</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>অটো</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>বিশ্রাম প্রতিরোধ দিবস্তুনা দিয়ে যাওয়া</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>বিশ্রাম প্রতিরোধ সক্রিয় করা</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>প্রদর্শন সেটিংস</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>থিম: সোনালী</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>থিম: মোটা</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>থিম: অটো</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>বিশ্রাম প্রভাব</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>সвет</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>নিঃস্বাগত</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>অটোমেটিক</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>থিম</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>কোনো বার্তা নেই</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>নোটিফিকেশন সেটিংস</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>নোটিফিকেশন</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>DND মোড বন্ধ করুন</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>DND মোড চালু করুন</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>নোটিফিকেশন</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>ওনবোর্ড</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>সেটিংস</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>উচ্চ পরফরমেন্স</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>স্বার্থ্যিত</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>পাউর সেভার</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation>পরফরমেন্স স্বার্থ্যিত</translation>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>পাউর</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>পাওয়ার সেটিংস</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>ধারণ ক্ষমতা %1, %2 min বাকি আছে</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>ধারণ ক্ষমতা %1, %2 hr %3 min বাকি আছে</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>%1 চার্জ হচ্ছে, সম্পূর্ণ হতে %2 min বাকি আছে</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>%1 চার্জ হচ্ছে, সম্পূর্ণ হতে %2 hr %3 min বাকি আছে</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>ক্যাপাসিটি %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>%1 চার্জ করা হচ্ছে</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>ক্যাপাসিটি %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>ক্যাপাসিটি %1, পুরো অর্জিত</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>ক্যাপাসিটি %1, চarging না</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>ব্যাটারি</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>চarging, অপশনাল চarging সময় গণনা করছে</translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>শেষ ব্যবহার সময় গণনা করছে</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>%1 মিনিট শেষ</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>%1 ঘণ্টা %2 মিনিট শেষ</translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>চาร্জ করা হচ্ছে না</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>পুরোনো চার্জ হয়েছে</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>চার্জ হচ্ছে, %1 মিনিট পর পুরোনো হবে</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>চার্জ হচ্ছে, %1 ঘন্টা %2 মিনিট পর পুরোনো হবে</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>ক্যাপাসিটি %1, %2 ঘন্টা শেষ রয়েছে</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>%1 ঘন্টা শেষ রয়েছে</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>চার্জ হচ্ছে %1, %2 ঘন্টা পর পুরোনো হবে</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>চার্জ হচ্ছে, %1 ঘন্টা পর পুরোনো হবে</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>সুর</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>অজানা</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>বন্ধ করুন</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>সাময়িক ভাবে বন্ধ করুন</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>হায়বারনেট</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>লক করুন</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>লগ আউট করুন</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>পাওয়ার সেটিংস</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>পুনঃরায় চালু করুন</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>আপডেট এবং বন্ধ করুন</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>আপডেট এবং রিবুট করুন</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>বন্ধ করুন</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>ব্যবহারকারী বদলুন</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>আজ</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>মাসিক</translation>
    </message>
    <message>
        <source>y</source>
        <translation>বছর</translation>
    </message>
    <message>
        <source>m</source>
        <translation>মাস</translation>
    </message>
    <message>
        <source>d</source>
        <translation>দিন</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>সোমবার</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>মঙ্গলবার</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>বুধবার</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>বৃহস্পতিবার</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>শুক্রবার</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>শনিবার</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>বুধবার</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation>জানুয়ারী</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>ফেব্রুয়ারী</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>মার্চ</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>এপ্রিল</translation>
    </message>
    <message>
        <source>May</source>
        <translation>মে</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>জুন</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>জুলাই</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>আগস্ট</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>সেপ্টেম্বর</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>অক্টোবর</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>নভেম্বর</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>ডিসেম্বর</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>ক্যালেন্ডার খুলুন</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>সোমবার</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>মঙ্গলবার</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>বুধবার</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>বৃহস্পতিবার</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>শুক্রবার</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>শনিবার</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>রবিবার</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>ভাস্কর্য</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>উত্তরাধিকার</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>সোনার সেটিংস</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>শব্দ</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>মুটে</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>মাথুরা</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>স্বর নিয়ন্ত্রণ</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>কোনো প্রেরণা উপকরণ নেই</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>%1 আওয়াজ</translation>
    </message>
</context>
</TS>